# LLV Steuererklaerung FL
# 2016-2025 foo.li systeme + software

$packageName    = 'etax-fl'
$fileType       = 'msi'
$silentArgs     = '/qn /norestart'
$checksumNP     = '3d61f360f5211cb23863a7bb81cf7e4bee39041f'
$checksumNP64   = '109e8757839b35c355fce768e7a9ad4605761ba9'
$checksumJP     = 'c6d06a08b40d4a4399fd59255f0760375155824f'
$checksumJP64   = '78c642feed715f4688f841225997e405b16ef2cd'
$checksumType   = 'sha1'
$validExitCodes = @(0,3010)

$arguments = @{}

# Now we can use the $env:chocolateyPackageParameters inside the Chocolatey package
$packageParameters = $env:chocolateyPackageParameters

#defaults
$edition = 'np'

# Now parse the packageParameters using good old regular expression
if ($packageParameters) {
    $match_pattern = "\/(?<option>([a-zA-Z]+)):(?<value>([`"'])?([a-zA-Z0-9- _\\:\.]+)([`"'])?)|\/(?<option>([a-zA-Z]+))"
    $option_name = 'option'
    $value_name = 'value'

    if ($packageParameters -match $match_pattern ){
        $results = $packageParameters | Select-String $match_pattern -AllMatches
        $results.matches | % {
          $arguments.Add(
              $_.Groups[$option_name].Value.Trim(),
              $_.Groups[$value_name].Value.Trim())
      }
    }
    else
    {
        Throw "Package Parameters were found but were invalid (REGEX Failure)"
    }
    if ($arguments.ContainsKey("edition")) {
        Write-Host "edition argument found"
        $edition = $arguments["edition"]
    } else {
        Write-Debug "No Package Parameters Passed in"
    }
}

if ([Environment]::OSVersion.Version -lt (new-object 'Version' 6,0)) {
    Write-Warning $(wasd
     'Windows Vista minimum required'
    )
    throw 'OS too old'
}

if ($edition -eq 'np') {
    #Write-Host 'going to install eTax NP (natrliche Personen)'
    #Write-Warning 'in march 2023 available...'
    #throw 'NP is available in march 2023'
    if (!($ENV:PROCESSOR_ARCHITECTURE="AMD64")) {
      $url = 'https://downloads.llv.li/stv/etax/update/etaxflnp/2024/etaxflnp2024-1.0.1-53-32bit.msi'
      $checksum = $checksumNP
    } else {
      $url64 = 'https://downloads.llv.li/stv/etax/update/etaxflnp/2024/etaxflnp2024-1.0.1-53-64bit.msi'
      $checksum = $checksumNP64
    }
} elseif ($edition -eq 'jp') {
    Write-Host 'going to install eTax JP (juristische Personen)'
    if (!($ENV:PROCESSOR_ARCHITECTURE="AMD64")) {
      $url = 'https://downloads.llv.li/stv/etax/update/etaxfljp/2024/etaxfljp2024-1.0.5-49-32bit.msi'
      $checksum = $checksumJP
    } else {
      $url64 = 'https://downloads.llv.li/stv/etax/update/etaxfljp/2024/etaxfljp2024-1.0.5-49-64bit.msi'
      $checksum = $checksumJP64
    }

} else {
    Write-Warning "please choose either 'np' or 'jp' with the /edition parameter"
    throw 'unknown edition'
}

$packageSearch = 'eTax FL 2024 ' + $edition

try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
        -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }
    if ($app) {
        Write-Host 'eTax' $edition 'is already installed.'
    } else {
        Install-ChocolateyPackage $packageName $fileType $silentArgs $url $url64 `
        -checksum $checksum -checksumType $checksumType -validExitCodes $validExitCodes
        Remove-Item -Path "$env:PUBLIC\Desktop\eTax FL 2023*.lnk" -ErrorAction SilentlyContinue
        Remove-Item -Path "$env:allusersprofile\Microsoft\Windows\Start Menu\Programs\eTax FL 2024 JP\Deinstallation eTax FL 2024*.lnk" -ErrorAction SilentlyContinue
        Remove-Item -Path "$env:allusersprofile\Microsoft\Windows\Start Menu\Programs\eTax FL 2024 NP\Deinstallation eTax FL 2024*.lnk" -ErrorAction SilentlyContinue
    }
} catch {
    throw $_.Exception
}
